package if::Pragmas;

our $DATE = '2014-10-09'; # DATE
our $VERSION = '0.01'; # VERSION

1;
# ABSTRACT: Various if::* pragmas

__END__

=pod

=encoding UTF-8

=head1 NAME

if::Pragmas - Various if::* pragmas

=head1 VERSION

This document describes version 0.01 of if::Pragmas (from Perl distribution if-Pragmas), released on 2014-10-09.

=head1 SYNOPSIS

=head1 DESCRIPTION

This distribution packages these modules:

 if::prog
 if::notprog

Please see respective module's documentation for more details.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/if-Pragmas>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-if-Pragmas>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=if-Pragmas>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
